# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'tidepoolTemplate_big.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1595, 810)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(1595, 810))
        MainWindow.setMaximumSize(QtCore.QSize(1595, 810))
        MainWindow.setSizeIncrement(QtCore.QSize(1, 1))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.imageData_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.imageData_groupBox.setGeometry(QtCore.QRect(440, 7, 561, 591))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Maximum
        )
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.imageData_groupBox.sizePolicy().hasHeightForWidth())
        self.imageData_groupBox.setSizePolicy(sizePolicy)
        self.imageData_groupBox.setMinimumSize(QtCore.QSize(550, 156))
        self.imageData_groupBox.setMaximumSize(QtCore.QSize(1100, 1000))
        self.imageData_groupBox.setSizeIncrement(QtCore.QSize(1, 1))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.imageData_groupBox.setFont(font)
        self.imageData_groupBox.setObjectName("imageData_groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.imageData_groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setSizeConstraint(QtCore.Qt.QLayout.SizeConstraint.SetMaximumSize)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setSizeConstraint(QtCore.Qt.QLayout.SizeConstraint.SetFixedSize)
        self.verticalLayout_3.setContentsMargins(-1, 5, -1, 5)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.dispmax_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.imageData_groupBox)
        self.dispmax_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.dispmax_doubleSpinBox.setDecimals(3)
        self.dispmax_doubleSpinBox.setObjectName("dispmax_doubleSpinBox")
        self.verticalLayout_3.addWidget(self.dispmax_doubleSpinBox)
        self.resetDispLimits_Button = QtWidgets.QPushButton(self.imageData_groupBox)
        self.resetDispLimits_Button.setObjectName("resetDispLimits_Button")
        self.verticalLayout_3.addWidget(self.resetDispLimits_Button)
        self.resetDispSmart_Button = QtWidgets.QPushButton(self.imageData_groupBox)
        self.resetDispSmart_Button.setObjectName("resetDispSmart_Button")
        self.verticalLayout_3.addWidget(self.resetDispSmart_Button)
        self.saveDisp_Button = QtWidgets.QPushButton(self.imageData_groupBox)
        self.saveDisp_Button.setObjectName("saveDisp_Button")
        self.verticalLayout_3.addWidget(self.saveDisp_Button)
        self.setMask_Button = QtWidgets.QPushButton(self.imageData_groupBox)
        self.setMask_Button.setObjectName("setMask_Button")
        self.verticalLayout_3.addWidget(self.setMask_Button)
        self.dispmin_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.imageData_groupBox)
        self.dispmin_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.dispmin_doubleSpinBox.setDecimals(3)
        self.dispmin_doubleSpinBox.setObjectName("dispmin_doubleSpinBox")
        self.verticalLayout_3.addWidget(self.dispmin_doubleSpinBox)
        self.transparency_checkBox = QtWidgets.QCheckBox(self.imageData_groupBox)
        self.transparency_checkBox.setChecked(False)
        self.transparency_checkBox.setObjectName("transparency_checkBox")
        self.verticalLayout_3.addWidget(self.transparency_checkBox)
        self.gridLayout_2.addLayout(self.verticalLayout_3, 0, 1, 1, 1)
        self.graphicsView_colorbar = GraphicsView(self.imageData_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.graphicsView_colorbar.sizePolicy().hasHeightForWidth())
        self.graphicsView_colorbar.setSizePolicy(sizePolicy)
        self.graphicsView_colorbar.setMinimumSize(QtCore.QSize(25, 128))
        self.graphicsView_colorbar.setMaximumSize(QtCore.QSize(25, 256))
        self.graphicsView_colorbar.setSizeIncrement(QtCore.QSize(0, 1))
        self.graphicsView_colorbar.setResizeAnchor(
            QtCore.Qt.QGraphicsView.ViewportAnchor.AnchorViewCenter
        )
        self.graphicsView_colorbar.setObjectName("graphicsView_colorbar")
        self.gridLayout_2.addWidget(self.graphicsView_colorbar, 0, 0, 1, 1)
        self.aspects_verticalLayout = QtWidgets.QVBoxLayout()
        self.aspects_verticalLayout.setSizeConstraint(
            QtCore.Qt.QLayout.SizeConstraint.SetMinimumSize
        )
        self.aspects_verticalLayout.setSpacing(0)
        self.aspects_verticalLayout.setObjectName("aspects_verticalLayout")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_2 = QtWidgets.QLabel(self.imageData_groupBox)
        self.label_2.setMaximumSize(QtCore.QSize(16777215, 14))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_4.addWidget(self.label_2)
        self.gray_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.gray_radioButton.setFont(font)
        self.gray_radioButton.setObjectName("gray_radioButton")
        self.colormap_buttonGroup = QtWidgets.QButtonGroup(MainWindow)
        self.colormap_buttonGroup.setObjectName("colormap_buttonGroup")
        self.colormap_buttonGroup.addButton(self.gray_radioButton)
        self.verticalLayout_4.addWidget(self.gray_radioButton)
        self.thermal_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.thermal_radioButton.setFont(font)
        self.thermal_radioButton.setObjectName("thermal_radioButton")
        self.colormap_buttonGroup.addButton(self.thermal_radioButton)
        self.verticalLayout_4.addWidget(self.thermal_radioButton)
        self.plasma_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.plasma_radioButton.setFont(font)
        self.plasma_radioButton.setObjectName("plasma_radioButton")
        self.colormap_buttonGroup.addButton(self.plasma_radioButton)
        self.verticalLayout_4.addWidget(self.plasma_radioButton)
        self.rainbow_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.rainbow_radioButton.setFont(font)
        self.rainbow_radioButton.setObjectName("rainbow_radioButton")
        self.colormap_buttonGroup.addButton(self.rainbow_radioButton)
        self.verticalLayout_4.addWidget(self.rainbow_radioButton)
        self.viridis_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.viridis_radioButton.setFont(font)
        self.viridis_radioButton.setObjectName("viridis_radioButton")
        self.colormap_buttonGroup.addButton(self.viridis_radioButton)
        self.verticalLayout_4.addWidget(self.viridis_radioButton)
        self.turbo_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.turbo_radioButton.setFont(font)
        self.turbo_radioButton.setObjectName("turbo_radioButton")
        self.colormap_buttonGroup.addButton(self.turbo_radioButton)
        self.verticalLayout_4.addWidget(self.turbo_radioButton)
        self.aspects_verticalLayout.addLayout(self.verticalLayout_4)
        self.summary_Label = QtWidgets.QLabel(self.imageData_groupBox)
        self.summary_Label.setMaximumSize(QtCore.QSize(16777215, 14))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.summary_Label.setFont(font)
        self.summary_Label.setObjectName("summary_Label")
        self.aspects_verticalLayout.addWidget(self.summary_Label)
        self.raw_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.raw_radioButton.setFont(font)
        self.raw_radioButton.setChecked(True)
        self.raw_radioButton.setObjectName("raw_radioButton")
        self.stats_buttonGroup = QtWidgets.QButtonGroup(MainWindow)
        self.stats_buttonGroup.setObjectName("stats_buttonGroup")
        self.stats_buttonGroup.addButton(self.raw_radioButton)
        self.aspects_verticalLayout.addWidget(self.raw_radioButton)
        self.mean_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.mean_radioButton.setFont(font)
        self.mean_radioButton.setChecked(False)
        self.mean_radioButton.setObjectName("mean_radioButton")
        self.stats_buttonGroup.addButton(self.mean_radioButton)
        self.aspects_verticalLayout.addWidget(self.mean_radioButton)
        self.median_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.median_radioButton.setFont(font)
        self.median_radioButton.setObjectName("median_radioButton")
        self.stats_buttonGroup.addButton(self.median_radioButton)
        self.aspects_verticalLayout.addWidget(self.median_radioButton)
        self.CoV_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.CoV_radioButton.setFont(font)
        self.CoV_radioButton.setObjectName("CoV_radioButton")
        self.stats_buttonGroup.addButton(self.CoV_radioButton)
        self.aspects_verticalLayout.addWidget(self.CoV_radioButton)
        self.std_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.std_radioButton.setFont(font)
        self.std_radioButton.setObjectName("std_radioButton")
        self.stats_buttonGroup.addButton(self.std_radioButton)
        self.aspects_verticalLayout.addWidget(self.std_radioButton)
        self.MAD_radioButton = QtWidgets.QRadioButton(self.imageData_groupBox)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.MAD_radioButton.setFont(font)
        self.MAD_radioButton.setObjectName("MAD_radioButton")
        self.stats_buttonGroup.addButton(self.MAD_radioButton)
        self.aspects_verticalLayout.addWidget(self.MAD_radioButton)
        self.gridLayout_2.addLayout(self.aspects_verticalLayout, 0, 2, 1, 1)
        self.gridLayout.addLayout(self.gridLayout_2, 2, 2, 1, 1)
        self.main_graphicsView_cor = GraphicsLayoutWidget(self.imageData_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.main_graphicsView_cor.sizePolicy().hasHeightForWidth())
        self.main_graphicsView_cor.setSizePolicy(sizePolicy)
        self.main_graphicsView_cor.setMinimumSize(QtCore.QSize(256, 128))
        self.main_graphicsView_cor.setMaximumSize(QtCore.QSize(256, 256))
        self.main_graphicsView_cor.setSizeIncrement(QtCore.QSize(1, 1))
        self.main_graphicsView_cor.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.main_graphicsView_cor.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.main_graphicsView_cor.setObjectName("main_graphicsView_cor")
        self.gridLayout.addWidget(self.main_graphicsView_cor, 1, 2, 1, 1)
        self.main_graphicsView_sag = GraphicsLayoutWidget(self.imageData_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.main_graphicsView_sag.sizePolicy().hasHeightForWidth())
        self.main_graphicsView_sag.setSizePolicy(sizePolicy)
        self.main_graphicsView_sag.setMinimumSize(QtCore.QSize(256, 256))
        self.main_graphicsView_sag.setMaximumSize(QtCore.QSize(256, 256))
        self.main_graphicsView_sag.setSizeIncrement(QtCore.QSize(1, 1))
        self.main_graphicsView_sag.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.main_graphicsView_sag.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.main_graphicsView_sag.setObjectName("main_graphicsView_sag")
        self.gridLayout.addWidget(self.main_graphicsView_sag, 2, 1, 1, 1)
        self.main_graphicsView_ax = GraphicsLayoutWidget(self.imageData_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.main_graphicsView_ax.sizePolicy().hasHeightForWidth())
        self.main_graphicsView_ax.setSizePolicy(sizePolicy)
        self.main_graphicsView_ax.setMinimumSize(QtCore.QSize(256, 256))
        self.main_graphicsView_ax.setMaximumSize(QtCore.QSize(256, 256))
        self.main_graphicsView_ax.setSizeIncrement(QtCore.QSize(1, 1))
        self.main_graphicsView_ax.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.main_graphicsView_ax.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.main_graphicsView_ax.setViewportUpdateMode(
            QtCore.Qt.QGraphicsView.ViewportUpdateMode.SmartViewportUpdate
        )
        self.main_graphicsView_ax.setObjectName("main_graphicsView_ax")
        self.gridLayout.addWidget(self.main_graphicsView_ax, 1, 1, 1, 1)
        self.overlays_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.overlays_groupBox.setGeometry(QtCore.QRect(10, 7, 421, 591))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlays_groupBox.sizePolicy().hasHeightForWidth())
        self.overlays_groupBox.setSizePolicy(sizePolicy)
        self.overlays_groupBox.setMinimumSize(QtCore.QSize(210, 0))
        self.overlays_groupBox.setMaximumSize(QtCore.QSize(16777215, 683))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.overlays_groupBox.setFont(font)
        self.overlays_groupBox.setObjectName("overlays_groupBox")
        self.overlay_radioButton_05 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_05.setGeometry(QtCore.QRect(10, 351, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_05.setFont(font)
        self.overlay_radioButton_05.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_05.setObjectName("overlay_radioButton_05")
        self.overlay_graphicsView_01 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_01.setGeometry(QtCore.QRect(10, 25, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_01.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_01.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_01.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_01.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_01.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_01.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_01.setObjectName("overlay_graphicsView_01")
        self.overlay_radioButton_01 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_01.setGeometry(QtCore.QRect(10, 71, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_01.setFont(font)
        self.overlay_radioButton_01.setAutoFillBackground(False)
        self.overlay_radioButton_01.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_01.setObjectName("overlay_radioButton_01")
        self.overlay_radioButton_02 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_02.setGeometry(QtCore.QRect(10, 141, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_02.setFont(font)
        self.overlay_radioButton_02.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_02.setObjectName("overlay_radioButton_02")
        self.overlay_radioButton_03 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_03.setGeometry(QtCore.QRect(10, 211, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_03.setFont(font)
        self.overlay_radioButton_03.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_03.setObjectName("overlay_radioButton_03")
        self.overlay_radioButton_04 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_04.setGeometry(QtCore.QRect(10, 281, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_04.setFont(font)
        self.overlay_radioButton_04.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_04.setObjectName("overlay_radioButton_04")
        self.corrout_radioButton = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.corrout_radioButton.setGeometry(QtCore.QRect(10, 620, 151, 20))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        font.setPointSize(10)
        self.corrout_radioButton.setFont(font)
        self.corrout_radioButton.setChecked(True)
        self.corrout_radioButton.setObjectName("corrout_radioButton")
        self.overlay_radioButton_06 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_06.setGeometry(QtCore.QRect(10, 421, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_06.setFont(font)
        self.overlay_radioButton_06.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_06.setObjectName("overlay_radioButton_06")
        self.overlay_radioButton_07 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_07.setGeometry(QtCore.QRect(10, 491, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_07.setFont(font)
        self.overlay_radioButton_07.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_07.setObjectName("overlay_radioButton_07")
        self.overlay_radioButton_08 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_08.setGeometry(QtCore.QRect(10, 561, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_08.setFont(font)
        self.overlay_radioButton_08.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_08.setObjectName("overlay_radioButton_08")
        self.overlay_graphicsView_04 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_04.setGeometry(QtCore.QRect(10, 235, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_04.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_04.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_04.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_04.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_04.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_04.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_04.setObjectName("overlay_graphicsView_04")
        self.overlay_graphicsView_06 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_06.setGeometry(QtCore.QRect(10, 375, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_06.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_06.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_06.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_06.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_06.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_06.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_06.setObjectName("overlay_graphicsView_06")
        self.overlay_graphicsView_03 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_03.setGeometry(QtCore.QRect(10, 165, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_03.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_03.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_03.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_03.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_03.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_03.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_03.setObjectName("overlay_graphicsView_03")
        self.overlay_graphicsView_08 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_08.setGeometry(QtCore.QRect(10, 515, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_08.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_08.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_08.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_08.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_08.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_08.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_08.setObjectName("overlay_graphicsView_08")
        self.overlay_graphicsView_05 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_05.setGeometry(QtCore.QRect(10, 305, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_05.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_05.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_05.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_05.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_05.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_05.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_05.setObjectName("overlay_graphicsView_05")
        self.overlay_graphicsView_02 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_02.setGeometry(QtCore.QRect(10, 95, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_02.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_02.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_02.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_02.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_02.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_02.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_02.setObjectName("overlay_graphicsView_02")
        self.overlay_graphicsView_07 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_07.setGeometry(QtCore.QRect(10, 445, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_07.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_07.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_07.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_07.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_07.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_07.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_07.setObjectName("overlay_graphicsView_07")
        self.overlay_graphicsView_09 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_09.setGeometry(QtCore.QRect(210, 25, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_09.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_09.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_09.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_09.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_09.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_09.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_09.setObjectName("overlay_graphicsView_09")
        self.overlay_graphicsView_11 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_11.setGeometry(QtCore.QRect(210, 165, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_11.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_11.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_11.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_11.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_11.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_11.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_11.setObjectName("overlay_graphicsView_11")
        self.overlay_graphicsView_10 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_10.setGeometry(QtCore.QRect(210, 95, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_10.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_10.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_10.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_10.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_10.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_10.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_10.setObjectName("overlay_graphicsView_10")
        self.overlay_graphicsView_12 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_12.setGeometry(QtCore.QRect(210, 235, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_12.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_12.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_12.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_12.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_12.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_12.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_12.setObjectName("overlay_graphicsView_12")
        self.overlay_graphicsView_13 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_13.setGeometry(QtCore.QRect(210, 305, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_13.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_13.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_13.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_13.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_13.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_13.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_13.setObjectName("overlay_graphicsView_13")
        self.overlay_graphicsView_14 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_14.setGeometry(QtCore.QRect(210, 375, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_14.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_14.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_14.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_14.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_14.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_14.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_14.setObjectName("overlay_graphicsView_14")
        self.overlay_graphicsView_15 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_15.setGeometry(QtCore.QRect(210, 445, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_15.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_15.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_15.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_15.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_15.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_15.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_15.setObjectName("overlay_graphicsView_15")
        self.overlay_graphicsView_16 = GraphicsLayoutWidget(self.overlays_groupBox)
        self.overlay_graphicsView_16.setGeometry(QtCore.QRect(210, 515, 192, 64))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.overlay_graphicsView_16.sizePolicy().hasHeightForWidth())
        self.overlay_graphicsView_16.setSizePolicy(sizePolicy)
        self.overlay_graphicsView_16.setMinimumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_16.setMaximumSize(QtCore.QSize(192, 64))
        self.overlay_graphicsView_16.setFrameShape(QtCore.Qt.QFrame.Shape.NoFrame)
        self.overlay_graphicsView_16.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.overlay_graphicsView_16.setObjectName("overlay_graphicsView_16")
        self.overlay_radioButton_09 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_09.setGeometry(QtCore.QRect(210, 70, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_09.setFont(font)
        self.overlay_radioButton_09.setAutoFillBackground(False)
        self.overlay_radioButton_09.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_09.setObjectName("overlay_radioButton_09")
        self.overlay_radioButton_10 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_10.setGeometry(QtCore.QRect(210, 140, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_10.setFont(font)
        self.overlay_radioButton_10.setAutoFillBackground(False)
        self.overlay_radioButton_10.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_10.setObjectName("overlay_radioButton_10")
        self.overlay_radioButton_11 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_11.setGeometry(QtCore.QRect(210, 210, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_11.setFont(font)
        self.overlay_radioButton_11.setAutoFillBackground(False)
        self.overlay_radioButton_11.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_11.setObjectName("overlay_radioButton_11")
        self.overlay_radioButton_12 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_12.setGeometry(QtCore.QRect(210, 280, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_12.setFont(font)
        self.overlay_radioButton_12.setAutoFillBackground(False)
        self.overlay_radioButton_12.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_12.setObjectName("overlay_radioButton_12")
        self.overlay_radioButton_13 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_13.setGeometry(QtCore.QRect(210, 350, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_13.setFont(font)
        self.overlay_radioButton_13.setAutoFillBackground(False)
        self.overlay_radioButton_13.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_13.setObjectName("overlay_radioButton_13")
        self.overlay_radioButton_14 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_14.setGeometry(QtCore.QRect(210, 420, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_14.setFont(font)
        self.overlay_radioButton_14.setAutoFillBackground(False)
        self.overlay_radioButton_14.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_14.setObjectName("overlay_radioButton_14")
        self.overlay_radioButton_15 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_15.setGeometry(QtCore.QRect(210, 490, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_15.setFont(font)
        self.overlay_radioButton_15.setAutoFillBackground(False)
        self.overlay_radioButton_15.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_15.setObjectName("overlay_radioButton_15")
        self.overlay_radioButton_16 = QtWidgets.QRadioButton(self.overlays_groupBox)
        self.overlay_radioButton_16.setGeometry(QtCore.QRect(210, 560, 151, 20))
        font = QtGui.QFont()
        font.setFamily(".AppleSystemUIFont")
        font.setPointSize(10)
        self.overlay_radioButton_16.setFont(font)
        self.overlay_radioButton_16.setAutoFillBackground(False)
        self.overlay_radioButton_16.setStyleSheet("color: rgb(255, 255, 255);")
        self.overlay_radioButton_16.setObjectName("overlay_radioButton_16")
        self.overlay_graphicsView_04.raise_()
        self.overlay_graphicsView_01.raise_()
        self.overlay_radioButton_01.raise_()
        self.overlay_radioButton_04.raise_()
        self.overlay_graphicsView_06.raise_()
        self.overlay_graphicsView_08.raise_()
        self.overlay_graphicsView_05.raise_()
        self.overlay_graphicsView_02.raise_()
        self.overlay_graphicsView_07.raise_()
        self.overlay_radioButton_02.raise_()
        self.overlay_graphicsView_03.raise_()
        self.overlay_radioButton_03.raise_()
        self.overlay_radioButton_06.raise_()
        self.overlay_radioButton_08.raise_()
        self.overlay_radioButton_07.raise_()
        self.overlay_radioButton_05.raise_()
        self.corrout_radioButton.raise_()
        self.overlay_graphicsView_09.raise_()
        self.overlay_graphicsView_11.raise_()
        self.overlay_graphicsView_10.raise_()
        self.overlay_graphicsView_12.raise_()
        self.overlay_graphicsView_13.raise_()
        self.overlay_graphicsView_14.raise_()
        self.overlay_graphicsView_15.raise_()
        self.overlay_graphicsView_16.raise_()
        self.overlay_radioButton_09.raise_()
        self.overlay_radioButton_10.raise_()
        self.overlay_radioButton_11.raise_()
        self.overlay_radioButton_12.raise_()
        self.overlay_radioButton_13.raise_()
        self.overlay_radioButton_14.raise_()
        self.overlay_radioButton_15.raise_()
        self.overlay_radioButton_16.raise_()
        self.histogram_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.histogram_groupBox.setGeometry(QtCore.QRect(1010, 225, 571, 186))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.histogram_groupBox.sizePolicy().hasHeightForWidth())
        self.histogram_groupBox.setSizePolicy(sizePolicy)
        self.histogram_groupBox.setMinimumSize(QtCore.QSize(100, 100))
        self.histogram_groupBox.setMaximumSize(QtCore.QSize(800, 1000))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.histogram_groupBox.setFont(font)
        self.histogram_groupBox.setObjectName("histogram_groupBox")
        self.histogram_graphicsView = GraphicsLayoutWidget(self.histogram_groupBox)
        self.histogram_graphicsView.setGeometry(QtCore.QRect(10, 25, 551, 151))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.histogram_graphicsView.sizePolicy().hasHeightForWidth())
        self.histogram_graphicsView.setSizePolicy(sizePolicy)
        self.histogram_graphicsView.setMinimumSize(QtCore.QSize(0, 100))
        self.histogram_graphicsView.setMaximumSize(QtCore.QSize(1000, 1000))
        self.histogram_graphicsView.setObjectName("histogram_graphicsView")
        self.mainimagedata_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.mainimagedata_groupBox.setGeometry(QtCore.QRect(1010, 7, 181, 221))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.mainimagedata_groupBox.setFont(font)
        self.mainimagedata_groupBox.setObjectName("mainimagedata_groupBox")
        self.label_4 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_4.setGeometry(QtCore.QRect(10, 35, 16, 16))
        self.label_4.setObjectName("label_4")
        self.pixnumX_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.pixnumX_doubleSpinBox.setGeometry(QtCore.QRect(30, 30, 67, 24))
        self.pixnumX_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.pixnumX_doubleSpinBox.setDecimals(0)
        self.pixnumX_doubleSpinBox.setObjectName("pixnumX_doubleSpinBox")
        self.label_7 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_7.setGeometry(QtCore.QRect(30, 20, 56, 13))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.coordX_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.coordX_doubleSpinBox.setGeometry(QtCore.QRect(100, 30, 67, 24))
        self.coordX_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.coordX_doubleSpinBox.setDecimals(3)
        self.coordX_doubleSpinBox.setObjectName("coordX_doubleSpinBox")
        self.label_9 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_9.setGeometry(QtCore.QRect(100, 20, 56, 13))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.pixnumY_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.pixnumY_doubleSpinBox.setGeometry(QtCore.QRect(30, 55, 67, 24))
        self.pixnumY_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.pixnumY_doubleSpinBox.setDecimals(0)
        self.pixnumY_doubleSpinBox.setObjectName("pixnumY_doubleSpinBox")
        self.coordY_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.coordY_doubleSpinBox.setGeometry(QtCore.QRect(100, 55, 67, 24))
        self.coordY_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.coordY_doubleSpinBox.setDecimals(3)
        self.coordY_doubleSpinBox.setObjectName("coordY_doubleSpinBox")
        self.pixnumZ_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.pixnumZ_doubleSpinBox.setGeometry(QtCore.QRect(30, 80, 67, 24))
        self.pixnumZ_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.pixnumZ_doubleSpinBox.setDecimals(0)
        self.pixnumZ_doubleSpinBox.setObjectName("pixnumZ_doubleSpinBox")
        self.coordZ_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.coordZ_doubleSpinBox.setGeometry(QtCore.QRect(100, 80, 67, 24))
        self.coordZ_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.coordZ_doubleSpinBox.setDecimals(3)
        self.coordZ_doubleSpinBox.setObjectName("coordZ_doubleSpinBox")
        self.label_6 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_6.setGeometry(QtCore.QRect(10, 60, 16, 16))
        self.label_6.setObjectName("label_6")
        self.label_8 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_8.setGeometry(QtCore.QRect(10, 85, 16, 16))
        self.label_8.setObjectName("label_8")
        self.coordT_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.coordT_doubleSpinBox.setGeometry(QtCore.QRect(100, 130, 67, 24))
        self.coordT_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.coordT_doubleSpinBox.setDecimals(3)
        self.coordT_doubleSpinBox.setObjectName("coordT_doubleSpinBox")
        self.pixnumT_doubleSpinBox = QtWidgets.QDoubleSpinBox(self.mainimagedata_groupBox)
        self.pixnumT_doubleSpinBox.setGeometry(QtCore.QRect(30, 130, 67, 24))
        self.pixnumT_doubleSpinBox.setAlignment(
            QtCore.Qt.Qt.AlignmentFlag.AlignRight
            | QtCore.Qt.Qt.AlignmentFlag.AlignTrailing
            | QtCore.Qt.Qt.AlignmentFlag.AlignVCenter
        )
        self.pixnumT_doubleSpinBox.setDecimals(0)
        self.pixnumT_doubleSpinBox.setObjectName("pixnumT_doubleSpinBox")
        self.label_3 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_3.setGeometry(QtCore.QRect(10, 135, 16, 16))
        self.label_3.setObjectName("label_3")
        self.TimeSlider = QtWidgets.QSlider(self.mainimagedata_groupBox)
        self.TimeSlider.setGeometry(QtCore.QRect(10, 195, 151, 22))
        self.TimeSlider.setOrientation(QtCore.Qt.Qt.Orientation.Horizontal)
        self.TimeSlider.setObjectName("TimeSlider")
        self.label_10 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_10.setGeometry(QtCore.QRect(30, 120, 56, 13))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_10.setFont(font)
        self.label_10.setObjectName("label_10")
        self.label_11 = QtWidgets.QLabel(self.mainimagedata_groupBox)
        self.label_11.setGeometry(QtCore.QRect(100, 120, 56, 13))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.runMovieButton = QtWidgets.QPushButton(self.mainimagedata_groupBox)
        self.runMovieButton.setGeometry(QtCore.QRect(20, 160, 151, 32))
        self.runMovieButton.setObjectName("runMovieButton")
        self.regressor_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.regressor_groupBox.setGeometry(QtCore.QRect(10, 595, 1571, 181))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.regressor_groupBox.sizePolicy().hasHeightForWidth())
        self.regressor_groupBox.setSizePolicy(sizePolicy)
        self.regressor_groupBox.setMinimumSize(QtCore.QSize(100, 100))
        self.regressor_groupBox.setMaximumSize(QtCore.QSize(1590, 1000))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.regressor_groupBox.setFont(font)
        self.regressor_groupBox.setObjectName("regressor_groupBox")
        self.regressorspectrum_graphicsView = GraphicsLayoutWidget(self.regressor_groupBox)
        self.regressorspectrum_graphicsView.setGeometry(QtCore.QRect(730, 25, 710, 131))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.regressorspectrum_graphicsView.sizePolicy().hasHeightForWidth()
        )
        self.regressorspectrum_graphicsView.setSizePolicy(sizePolicy)
        self.regressorspectrum_graphicsView.setMinimumSize(QtCore.QSize(710, 100))
        self.regressorspectrum_graphicsView.setMaximumSize(QtCore.QSize(710, 1000))
        self.regressorspectrum_graphicsView.setSizeIncrement(QtCore.QSize(1, 1))
        self.regressorspectrum_graphicsView.setObjectName("regressorspectrum_graphicsView")
        self.regressortimecourse_graphicsView = GraphicsLayoutWidget(self.regressor_groupBox)
        self.regressortimecourse_graphicsView.setEnabled(True)
        self.regressortimecourse_graphicsView.setGeometry(QtCore.QRect(10, 23, 710, 131))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(
            self.regressortimecourse_graphicsView.sizePolicy().hasHeightForWidth()
        )
        self.regressortimecourse_graphicsView.setSizePolicy(sizePolicy)
        self.regressortimecourse_graphicsView.setMinimumSize(QtCore.QSize(710, 100))
        self.regressortimecourse_graphicsView.setMaximumSize(QtCore.QSize(710, 1000))
        self.regressortimecourse_graphicsView.setSizeIncrement(QtCore.QSize(1, 1))
        self.regressortimecourse_graphicsView.setObjectName("regressortimecourse_graphicsView")
        self.processingstage_groupBox = QtWidgets.QGroupBox(self.regressor_groupBox)
        self.processingstage_groupBox.setGeometry(QtCore.QRect(1450, 5, 120, 151))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.processingstage_groupBox.setFont(font)
        self.processingstage_groupBox.setObjectName("processingstage_groupBox")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.processingstage_groupBox)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 25, 101, 122))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.prefilt_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.prefilt_radioButton.setFont(font)
        self.prefilt_radioButton.setChecked(True)
        self.prefilt_radioButton.setObjectName("prefilt_radioButton")
        self.verticalLayout.addWidget(self.prefilt_radioButton)
        self.postfilt_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.postfilt_radioButton.setFont(font)
        self.postfilt_radioButton.setChecked(False)
        self.postfilt_radioButton.setObjectName("postfilt_radioButton")
        self.verticalLayout.addWidget(self.postfilt_radioButton)
        self.pass1_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.pass1_radioButton.setFont(font)
        self.pass1_radioButton.setObjectName("pass1_radioButton")
        self.verticalLayout.addWidget(self.pass1_radioButton)
        self.pass2_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.pass2_radioButton.setFont(font)
        self.pass2_radioButton.setObjectName("pass2_radioButton")
        self.verticalLayout.addWidget(self.pass2_radioButton)
        self.pass3_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.pass3_radioButton.setFont(font)
        self.pass3_radioButton.setObjectName("pass3_radioButton")
        self.verticalLayout.addWidget(self.pass3_radioButton)
        self.pass4_radioButton = QtWidgets.QRadioButton(self.verticalLayoutWidget)
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.pass4_radioButton.setFont(font)
        self.pass4_radioButton.setObjectName("pass4_radioButton")
        self.verticalLayout.addWidget(self.pass4_radioButton)
        spacerItem = QtWidgets.QSpacerItem(
            20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
        )
        self.verticalLayout.addItem(spacerItem)
        self.label_5 = QtWidgets.QLabel(self.regressor_groupBox)
        self.label_5.setGeometry(QtCore.QRect(270, 155, 161, 16))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_5.setFont(font)
        self.label_5.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.label_5.setObjectName("label_5")
        self.label_12 = QtWidgets.QLabel(self.regressor_groupBox)
        self.label_12.setGeometry(QtCore.QRect(1040, 155, 131, 16))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.label_12.setFont(font)
        self.label_12.setAlignment(QtCore.Qt.Qt.AlignmentFlag.AlignCenter)
        self.label_12.setObjectName("label_12")
        self.logOutput_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.logOutput_groupBox.setGeometry(QtCore.QRect(1200, 7, 381, 221))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.logOutput_groupBox.sizePolicy().hasHeightForWidth())
        self.logOutput_groupBox.setSizePolicy(sizePolicy)
        self.logOutput_groupBox.setMinimumSize(QtCore.QSize(100, 100))
        self.logOutput_groupBox.setMaximumSize(QtCore.QSize(700, 500))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.logOutput_groupBox.setFont(font)
        self.logOutput_groupBox.setObjectName("logOutput_groupBox")
        self.logOutput = QtWidgets.QTextEdit(self.logOutput_groupBox)
        self.logOutput.setGeometry(QtCore.QRect(10, 25, 361, 186))
        font = QtGui.QFont()
        font.setFamily("Courier New")
        font.setPointSize(11)
        font.setBold(True)
        self.logOutput.setFont(font)
        self.logOutput.setObjectName("logOutput")
        self.simfunc_groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.simfunc_groupBox.setGeometry(QtCore.QRect(1010, 407, 571, 186))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.simfunc_groupBox.sizePolicy().hasHeightForWidth())
        self.simfunc_groupBox.setSizePolicy(sizePolicy)
        self.simfunc_groupBox.setMinimumSize(QtCore.QSize(100, 100))
        self.simfunc_groupBox.setMaximumSize(QtCore.QSize(800, 1000))
        font = QtGui.QFont()
        font.setFamily("Arial Narrow")
        self.simfunc_groupBox.setFont(font)
        self.simfunc_groupBox.setObjectName("simfunc_groupBox")
        self.simfunc_graphicsView = GraphicsLayoutWidget(self.simfunc_groupBox)
        self.simfunc_graphicsView.setGeometry(QtCore.QRect(10, 25, 551, 151))
        sizePolicy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding
        )
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.simfunc_graphicsView.sizePolicy().hasHeightForWidth())
        self.simfunc_graphicsView.setSizePolicy(sizePolicy)
        self.simfunc_graphicsView.setMinimumSize(QtCore.QSize(0, 100))
        self.simfunc_graphicsView.setMaximumSize(QtCore.QSize(1000, 1000))
        self.simfunc_graphicsView.setObjectName("simfunc_graphicsView")
        self.overlays_groupBox.raise_()
        self.imageData_groupBox.raise_()
        self.histogram_groupBox.raise_()
        self.mainimagedata_groupBox.raise_()
        self.regressor_groupBox.raise_()
        self.logOutput_groupBox.raise_()
        self.simfunc_groupBox.raise_()
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1600, 24))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.imageData_groupBox.setTitle(_translate("MainWindow", "Image Data"))
        self.resetDispLimits_Button.setToolTip(
            _translate(
                "MainWindow",
                "Set the display range of the current map to the absolute minimum and maximum",
            )
        )
        self.resetDispLimits_Button.setText(_translate("MainWindow", "Full Range"))
        self.resetDispSmart_Button.setToolTip(
            _translate(
                "MainWindow",
                "Set the display range of the current map to the robust minimum and maximum",
            )
        )
        self.resetDispSmart_Button.setText(_translate("MainWindow", "Smart"))
        self.saveDisp_Button.setToolTip(
            _translate("MainWindow", "Save jpegs of the currently displayed map")
        )
        self.saveDisp_Button.setText(_translate("MainWindow", "Save"))
        self.setMask_Button.setToolTip(
            _translate(
                "MainWindow", "Right click to select the mask used to display the current map"
            )
        )
        self.setMask_Button.setText(_translate("MainWindow", "No mask"))
        self.transparency_checkBox.setToolTip(
            _translate(
                "MainWindow",
                "With transparency on, map values outside the range limits are not displayed.",
            )
        )
        self.transparency_checkBox.setText(_translate("MainWindow", "Transparency"))
        self.label_2.setText(_translate("MainWindow", "Colormap"))
        self.gray_radioButton.setText(_translate("MainWindow", "Gray"))
        self.thermal_radioButton.setText(_translate("MainWindow", "Thermal"))
        self.plasma_radioButton.setText(_translate("MainWindow", "Plasma"))
        self.rainbow_radioButton.setText(_translate("MainWindow", "Rainbow"))
        self.viridis_radioButton.setText(_translate("MainWindow", "Viridis"))
        self.turbo_radioButton.setText(_translate("MainWindow", "Turbo"))
        self.summary_Label.setText(_translate("MainWindow", "Region summaries"))
        self.raw_radioButton.setText(_translate("MainWindow", "Raw data"))
        self.mean_radioButton.setText(_translate("MainWindow", "Mean"))
        self.median_radioButton.setText(_translate("MainWindow", "Median"))
        self.CoV_radioButton.setText(_translate("MainWindow", "CoV"))
        self.std_radioButton.setText(_translate("MainWindow", "Std dev"))
        self.MAD_radioButton.setText(_translate("MainWindow", "MAD"))
        self.overlays_groupBox.setTitle(_translate("MainWindow", "Overlays"))
        self.overlay_radioButton_05.setText(_translate("MainWindow", "Mask"))
        self.overlay_radioButton_01.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_02.setText(_translate("MainWindow", "Correlation strength"))
        self.overlay_radioButton_03.setText(_translate("MainWindow", "MTT"))
        self.overlay_radioButton_04.setText(_translate("MainWindow", "R2"))
        self.corrout_radioButton.setText(_translate("MainWindow", "Correlation function"))
        self.overlay_radioButton_06.setText(_translate("MainWindow", "Mask"))
        self.overlay_radioButton_07.setText(_translate("MainWindow", "Mask"))
        self.overlay_radioButton_08.setText(_translate("MainWindow", "Mask"))
        self.overlay_radioButton_09.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_10.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_11.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_12.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_13.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_14.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_15.setText(_translate("MainWindow", "Lag times"))
        self.overlay_radioButton_16.setText(_translate("MainWindow", "Lag times"))
        self.histogram_groupBox.setTitle(_translate("MainWindow", "Overlay Histogram"))
        self.mainimagedata_groupBox.setTitle(_translate("MainWindow", "Location"))
        self.label_4.setText(_translate("MainWindow", "X"))
        self.label_7.setText(_translate("MainWindow", "Voxel"))
        self.label_9.setText(_translate("MainWindow", "mm"))
        self.label_6.setText(_translate("MainWindow", "Y"))
        self.label_8.setText(_translate("MainWindow", "Z"))
        self.label_3.setText(_translate("MainWindow", "T"))
        self.label_10.setText(_translate("MainWindow", "Timepoint"))
        self.label_11.setText(_translate("MainWindow", "seconds"))
        self.runMovieButton.setText(_translate("MainWindow", "Start Movie"))
        self.regressor_groupBox.setTitle(_translate("MainWindow", "Probe regressor"))
        self.processingstage_groupBox.setTitle(_translate("MainWindow", "Processing stage"))
        self.prefilt_radioButton.setText(_translate("MainWindow", "Prefilt"))
        self.postfilt_radioButton.setText(_translate("MainWindow", "Postfilt"))
        self.pass1_radioButton.setText(_translate("MainWindow", "Pass 1"))
        self.pass2_radioButton.setText(_translate("MainWindow", "Pass 2"))
        self.pass3_radioButton.setText(_translate("MainWindow", "Pass 3"))
        self.pass4_radioButton.setText(_translate("MainWindow", "Pass 4"))
        self.label_5.setText(_translate("MainWindow", "Timecourse (seconds)"))
        self.label_12.setText(_translate("MainWindow", "Power spectrum (Hz)"))
        self.logOutput_groupBox.setTitle(_translate("MainWindow", "Information"))
        self.simfunc_groupBox.setTitle(_translate("MainWindow", "Correlation Function"))
        self.actionQuit.setText(_translate("MainWindow", "Quit"))


from pyqtgraph import GraphicsLayoutWidget, GraphicsView



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   Copyright 2016-2026 Blaise Frederick
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#
import os

import matplotlib as mpl

import rapidtide.qualitycheck as rapidtide_quality
import rapidtide.workflows.rapidtide as rapidtide_workflow
import rapidtide.workflows.rapidtide_parser as rapidtide_parser
from rapidtide.tests.utils import get_examples_path, get_test_temp_path


def test_fullrunrapidtide_v8(debug=False, local=False, displayplots=False):
    # set input and output directories
    exampleroot = get_examples_path(local)
    testtemproot = get_test_temp_path(local)

    # run rapidtide
    inputargs = [
        os.path.join(exampleroot, "sub-RAPIDTIDETEST.nii.gz"),
        os.path.join(testtemproot, "sub-RAPIDTIDETEST8"),
        "--spatialfilt",
        "2",
        "--simcalcrange",
        "4",
        "-1",
        "--searchrange",
        "-5",
        "10",
        "--nprocs",
        "-1",
        "--passes",
        "1",
        "--despecklepasses",
        "3",
        "--similaritymetric",
        "riptide",
        "--riptidestep",
        "1.5",
    ]
    rapidtide_workflow.rapidtide_main(rapidtide_parser.process_args(inputargs=inputargs))


if __name__ == "__main__":
    mpl.use("TkAgg")
    test_fullrunrapidtide_v8(debug=True, local=True, displayplots=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   Copyright 2025-2026 Blaise Frederick
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#
import os

import numpy as np
import torch

import rapidtide.dlfiltertorch as dlfiltertorch
from rapidtide.tests.utils import get_test_temp_path, mse


def create_dummy_data():
    """Create dummy training data for testing."""
    window_size = 64
    num_samples = 100

    # Create dummy input and output data
    train_x = np.random.randn(num_samples, window_size, 1).astype(np.float32)
    train_y = np.random.randn(num_samples, window_size, 1).astype(np.float32)
    val_x = np.random.randn(20, window_size, 1).astype(np.float32)
    val_y = np.random.randn(20, window_size, 1).astype(np.float32)

    return {
        "train_x": train_x,
        "train_y": train_y,
        "val_x": val_x,
        "val_y": val_y,
        "window_size": window_size,
    }


def cnn_model_creation():
    """Test CNN model instantiation and forward pass."""
    num_filters = 10
    kernel_size = 5
    num_layers = 3
    dropout_rate = 0.3
    dilation_rate = 1
    activation = "relu"
    inputsize = 1

    model = dlfiltertorch.CNNModel(
        num_filters=num_filters,
        kernel_size=kernel_size,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        dilation_rate=dilation_rate,
        activation=activation,
        inputsize=inputsize,
    )

    # Test forward pass
    batch_size = 4
    seq_len = 64
    x = torch.randn(batch_size, inputsize, seq_len)
    output = model(x)

    assert output.shape == (batch_size, inputsize, seq_len)

    # Test get_config
    config = model.get_config()
    assert config["num_filters"] == num_filters
    assert config["kernel_size"] == kernel_size


def cnn_dlfilter_initialization(testtemproot):
    """Test CNNDLFilter initialization."""
    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
    )

    assert filter_obj.window_size == 64
    assert filter_obj.num_filters == 10
    assert filter_obj.kernel_size == 5
    assert filter_obj.nettype == "cnn"
    assert not filter_obj.initialized


def cnn_dlfilter_initialize(testtemproot):
    """Test CNNDLFilter model initialization."""
    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    # Just call getname and makenet, don't call full initialize
    # because savemodel has a bug using modelname instead of modelpath
    filter_obj.getname()
    filter_obj.makenet()

    assert filter_obj.model is not None
    assert os.path.exists(filter_obj.modelpath)

    # Manually save using modelpath
    filter_obj.model.to(filter_obj.device)
    filter_obj.savemodel(altname=filter_obj.modelpath)

    assert os.path.exists(os.path.join(filter_obj.modelpath, "model.pth"))


def predict_model(testtemproot, dummy_data):
    """Test the predict_model method."""
    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=dummy_data["window_size"],
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
    )

    # Just create the model without full initialize
    filter_obj.getname()
    filter_obj.makenet()
    filter_obj.model.to(filter_obj.device)

    # Test prediction with numpy array
    predictions = filter_obj.predict_model(dummy_data["val_x"])

    assert predictions.shape == dummy_data["val_y"].shape
    assert isinstance(predictions, np.ndarray)


def apply_method(testtemproot):
    """Test the apply method for filtering a signal."""
    window_size = 64
    signal_length = 500

    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=window_size,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
    )

    # Just create the model without full initialize
    filter_obj.getname()
    filter_obj.makenet()
    filter_obj.model.to(filter_obj.device)

    # Create a test signal
    input_signal = np.random.randn(signal_length).astype(np.float32)

    # Apply the filter
    filtered_signal = filter_obj.apply(input_signal)

    assert filtered_signal.shape == input_signal.shape
    assert isinstance(filtered_signal, np.ndarray)


def apply_method_with_badpts(testtemproot):
    """Test the apply method with bad points."""
    window_size = 64
    signal_length = 500

    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=window_size,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        usebadpts=True,
    )

    # Just create the model without full initialize
    filter_obj.getname()
    filter_obj.makenet()
    filter_obj.model.to(filter_obj.device)

    # Create test signal and bad points
    input_signal = np.random.randn(signal_length).astype(np.float32)
    badpts = np.zeros(signal_length, dtype=np.float32)
    badpts[100:120] = 1.0  # Mark some points as bad

    # Apply the filter with bad points
    filtered_signal = filter_obj.apply(input_signal, badpts=badpts)

    assert filtered_signal.shape == input_signal.shape
    assert isinstance(filtered_signal, np.ndarray)


def save_and_load_model(testtemproot):
    """Test saving and loading a model."""
    # This test is skipped because both savemodel() and initmetadata()
    # use self.modelname (a relative path) instead of self.modelpath (full path)
    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="saveloadtest",
    )

    # Create and save the model using modelpath
    filter_obj.getname()
    filter_obj.makenet()
    filter_obj.model.to(filter_obj.device)
    filter_obj.initmetadata()
    filter_obj.savemodel(altname=filter_obj.modelpath)

    original_modelname = os.path.basename(filter_obj.modelpath)

    # Get original model weights
    original_weights = {}
    for name, param in filter_obj.model.named_parameters():
        original_weights[name] = param.data.clone()

    # Create new filter object and load the saved model
    filter_obj2 = dlfiltertorch.CNNDLFilter(
        num_filters=10,  # These will be overridden by loaded model
        kernel_size=5,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        modelpath=testtemproot,
    )

    filter_obj2.loadmodel(original_modelname)

    # Check that metadata was loaded correctly
    assert filter_obj2.window_size == 64
    assert filter_obj2.infodict["nettype"] == "cnn"

    # Verify weights match
    for name, param in filter_obj2.model.named_parameters():
        assert torch.allclose(original_weights[name], param.data)


def filtscale_forward():
    """Test filtscale function in forward direction."""
    # filtscale expects 1D data (single timecourse)
    data = np.random.randn(64)

    # Test without log normalization
    scaled_data, scalefac = dlfiltertorch.filtscale(data, reverse=False, lognormalize=False)

    assert scaled_data.shape == (64, 2)
    assert isinstance(scalefac, (float, np.floating))

    # Test with log normalization
    scaled_data_log, scalefac_log = dlfiltertorch.filtscale(data, reverse=False, lognormalize=True)

    assert scaled_data_log.shape == (64, 2)


def filtscale_reverse():
    """Test filtscale function in reverse direction."""
    # filtscale expects 1D data (single timecourse)
    data = np.random.randn(64)

    # Forward then reverse
    scaled_data, scalefac = dlfiltertorch.filtscale(data, reverse=False, lognormalize=False)

    reconstructed = dlfiltertorch.filtscale(
        scaled_data, scalefac=scalefac, reverse=True, lognormalize=False
    )

    # Should reconstruct approximately to original
    assert reconstructed.shape == data.shape
    assert mse(data, reconstructed) < 1.0  # Allow some reconstruction error


def tobadpts():
    """Test tobadpts helper function."""
    filename = "test_file.txt"
    result = dlfiltertorch.tobadpts(filename)
    assert result == "test_file_badpts.txt"


def targettoinput():
    """Test targettoinput helper function."""
    filename = "test_xyz_file.txt"
    result = dlfiltertorch.targettoinput(filename, targetfrag="xyz", inputfrag="abc")
    assert result == "test_abc_file.txt"


def model_with_different_activations(testtemproot):
    """Test models with different activation functions."""
    activations = ["relu", "tanh"]

    for activation in activations:
        model = dlfiltertorch.CNNModel(
            num_filters=10,
            kernel_size=5,
            num_layers=3,
            dropout_rate=0.3,
            dilation_rate=1,
            activation=activation,
            inputsize=1,
        )

        # Test forward pass
        x = torch.randn(2, 1, 64)
        output = model(x)
        assert output.shape == x.shape

        config = model.get_config()
        assert config["activation"] == activation


def device_selection():
    """Test that device is properly set based on availability."""
    # This test just checks that the device variable is set
    # We can't guarantee CUDA/MPS availability in test environment
    assert dlfiltertorch.device in [torch.device("cuda"), torch.device("mps"), torch.device("cpu")]


def infodict_population(testtemproot):
    """Test that infodict is properly populated."""
    filter_obj = dlfiltertorch.CNNDLFilter(
        num_filters=10,
        kernel_size=5,
        window_size=64,
        num_layers=3,
        dropout_rate=0.3,
        num_epochs=5,
        excludethresh=4.0,
        corrthresh_rp=0.5,
        corrthresh_pp=0.9,
        modelroot=testtemproot,
    )

    # Check that infodict has expected keys
    assert "nettype" in filter_obj.infodict
    assert "num_filters" in filter_obj.infodict
    assert "kernel_size" in filter_obj.infodict
    assert filter_obj.infodict["nettype"] == "cnn"

    # Create the model (don't call initmetadata due to path bug)
    filter_obj.getname()
    filter_obj.makenet()

    # The model should populate infodict with window_size during getname
    assert "window_size" in filter_obj.infodict
    assert filter_obj.infodict["window_size"] == 64


def self_attention_model():
    """Test SelfAttention module forward pass and output shapes."""
    feature_dim = 32
    batch_size = 4
    seq_len = 20

    attn = dlfiltertorch.SelfAttention(feature_dim)
    x = torch.randn(batch_size, seq_len, feature_dim)
    out, weights = attn(x)

    assert out.shape == (batch_size, seq_len, feature_dim)
    assert weights.shape == (batch_size, seq_len)

    # Weights should sum to ~1 along last dim (softmax output averaged)
    # Just check they are non-negative
    assert torch.all(weights >= 0.0)


def ppg_attention_model_creation():
    """Test PPGAttentionModel instantiation and forward pass."""
    hidden_size = 32
    model = dlfiltertorch.PPGAttentionModel(hidden_size=hidden_size)

    # PPGAttentionModel expects (batch, 1, even_length)
    batch_size = 4
    x = torch.randn(batch_size, 1, 100)
    output = model(x)

    assert output.shape == (batch_size, 1, 100)

    # Test with different even-length input
    x2 = torch.randn(batch_size, 1, 64)
    output2 = model(x2)
    assert output2.shape == (batch_size, 1, 64)


def ppg_attention_dlfilter(testtemproot):
    """Test PPGAttentionDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.PPGAttentionDLFilter(
        hidden_size=32,
        window_size=100,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "ppgattention"
    assert filter_obj.hidden_size == 32

    filter_obj.getname()
    assert "ppgattention" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.PPGAttentionModel)

    # Test forward pass through DLFilter's predict_model
    val_x = np.random.randn(10, 100, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape


def dense_autoencoder_model_creation():
    """Test DenseAutoencoderModel instantiation and forward pass."""
    window_size = 64
    encoding_dim = 10
    num_layers = 4
    dropout_rate = 0.3
    activation = "relu"
    inputsize = 1

    model = dlfiltertorch.DenseAutoencoderModel(
        window_size=window_size,
        encoding_dim=encoding_dim,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        activation=activation,
        inputsize=inputsize,
    )
    model.eval()

    batch_size = 4
    x = torch.randn(batch_size, inputsize, window_size)
    output = model(x)

    assert output.shape == (batch_size, inputsize, window_size)

    # Test get_config
    config = model.get_config()
    assert config["window_size"] == window_size
    assert config["encoding_dim"] == encoding_dim
    assert config["num_layers"] == num_layers
    assert config["activation"] == activation

    # Test with tanh activation
    model_tanh = dlfiltertorch.DenseAutoencoderModel(
        window_size=window_size,
        encoding_dim=encoding_dim,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        activation="tanh",
        inputsize=inputsize,
    )
    model_tanh.eval()
    output_tanh = model_tanh(x)
    assert output_tanh.shape == (batch_size, inputsize, window_size)


def dense_autoencoder_dlfilter(testtemproot):
    """Test DenseAutoencoderDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.DenseAutoencoderDLFilter(
        encoding_dim=10,
        window_size=64,
        num_layers=4,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "autoencoder"
    assert filter_obj.encoding_dim == 10

    filter_obj.getname()
    assert "autoencoder" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.DenseAutoencoderModel)

    # Test predict
    val_x = np.random.randn(10, 64, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape


def conv_autoencoder_model_creation():
    """Test ConvAutoencoderModel instantiation and forward pass."""
    # Use window_size=65 (2^6+1) so MaxPool1d(2, padding=1) sizes match formula
    # 65 -> 33 -> 17 -> 9 -> 5 (all odd, formula matches actual)
    window_size = 65
    encoding_dim = 8
    num_filters = 4
    kernel_size = 3
    dropout_rate = 0.3
    activation = "relu"
    inputsize = 1

    model = dlfiltertorch.ConvAutoencoderModel(
        window_size=window_size,
        encoding_dim=encoding_dim,
        num_filters=num_filters,
        kernel_size=kernel_size,
        dropout_rate=dropout_rate,
        activation=activation,
        inputsize=inputsize,
    )
    model.eval()

    batch_size = 4
    x = torch.randn(batch_size, inputsize, window_size)
    output = model(x)

    assert output.shape == (batch_size, inputsize, window_size)

    # Test get_config
    config = model.get_config()
    assert config["window_size"] == window_size
    assert config["encoding_dim"] == encoding_dim
    assert config["num_filters"] == num_filters


def conv_autoencoder_dlfilter(testtemproot):
    """Test ConvAutoencoderDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.ConvAutoencoderDLFilter(
        encoding_dim=8,
        num_filters=4,
        kernel_size=3,
        window_size=65,
        num_layers=4,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "convautoencoder"

    filter_obj.getname()
    assert "convautoencoder" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.ConvAutoencoderModel)

    # Test predict
    val_x = np.random.randn(10, 65, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape


def multiscale_cnn_model_creation():
    """Test MultiscaleCNNModel instantiation and forward pass."""
    num_filters = 10
    kernel_sizes = [3, 5, 7]
    input_lens = [32, 64, 96]
    input_width = 1
    dilation_rate = 1

    model = dlfiltertorch.MultiscaleCNNModel(
        num_filters=num_filters,
        kernel_sizes=kernel_sizes,
        input_lens=input_lens,
        input_width=input_width,
        dilation_rate=dilation_rate,
    )
    model.eval()

    batch_size = 4
    x_small = torch.randn(batch_size, input_width, input_lens[0])
    x_med = torch.randn(batch_size, input_width, input_lens[1])
    x_large = torch.randn(batch_size, input_width, input_lens[2])

    output = model(x_small, x_med, x_large)

    # Output should be (batch_size, 1) with sigmoid
    assert output.shape == (batch_size, 1)
    assert torch.all(output >= 0.0) and torch.all(output <= 1.0)

    # Test get_config
    config = model.get_config()
    assert config["num_filters"] == num_filters
    assert config["kernel_sizes"] == kernel_sizes
    assert config["input_lens"] == input_lens


def multiscale_cnn_dlfilter(testtemproot):
    """Test MultiscaleCNNDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.MultiscaleCNNDLFilter(
        num_filters=10,
        kernel_sizes=[3, 5, 7],
        input_lens=[32, 64, 96],
        input_width=1,
        window_size=64,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "multiscalecnn"

    filter_obj.getname()
    assert "multiscalecnn" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.MultiscaleCNNModel)


def crnn_model_creation():
    """Test CRNNModel instantiation and forward pass."""
    num_filters = 8
    kernel_size = 3
    encoding_dim = 16
    dropout_rate = 0.3
    activation = "relu"
    inputsize = 1

    model = dlfiltertorch.CRNNModel(
        num_filters=num_filters,
        kernel_size=kernel_size,
        encoding_dim=encoding_dim,
        dropout_rate=dropout_rate,
        activation=activation,
        inputsize=inputsize,
    )
    model.eval()

    batch_size = 4
    seq_len = 64
    x = torch.randn(batch_size, inputsize, seq_len)
    output = model(x)

    assert output.shape == (batch_size, inputsize, seq_len)

    # Test get_config
    config = model.get_config()
    assert config["num_filters"] == num_filters
    assert config["kernel_size"] == kernel_size
    assert config["encoding_dim"] == encoding_dim
    assert config["activation"] == activation

    # Test with tanh
    model_tanh = dlfiltertorch.CRNNModel(
        num_filters=num_filters,
        kernel_size=kernel_size,
        encoding_dim=encoding_dim,
        dropout_rate=dropout_rate,
        activation="tanh",
        inputsize=inputsize,
    )
    model_tanh.eval()
    output_tanh = model_tanh(x)
    assert output_tanh.shape == (batch_size, inputsize, seq_len)


def crnn_dlfilter(testtemproot):
    """Test CRNNDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.CRNNDLFilter(
        encoding_dim=16,
        num_filters=8,
        kernel_size=3,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "crnn"

    filter_obj.getname()
    assert "crnn" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.CRNNModel)

    # Test predict
    val_x = np.random.randn(10, 64, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape


def lstm_model_creation():
    """Test LSTMModel instantiation and forward pass."""
    num_units = 16
    num_layers = 2
    dropout_rate = 0.3
    window_size = 64
    inputsize = 1

    model = dlfiltertorch.LSTMModel(
        num_units=num_units,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        window_size=window_size,
        inputsize=inputsize,
    )
    model.eval()

    batch_size = 4
    x = torch.randn(batch_size, inputsize, window_size)
    output = model(x)

    assert output.shape == (batch_size, inputsize, window_size)

    # Test get_config
    config = model.get_config()
    assert config["num_units"] == num_units
    assert config["num_layers"] == num_layers
    assert config["window_size"] == window_size
    assert config["inputsize"] == inputsize


def lstm_dlfilter(testtemproot):
    """Test LSTMDLFilter initialization, getname, makenet."""
    filter_obj = dlfiltertorch.LSTMDLFilter(
        num_units=16,
        window_size=64,
        num_layers=2,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "lstm"

    filter_obj.getname()
    assert "lstm" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.LSTMModel)

    # Test predict
    val_x = np.random.randn(10, 64, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape


def hybrid_model_creation():
    """Test HybridModel with both invert modes."""
    num_filters = 8
    kernel_size = 3
    num_units = 16
    num_layers = 3
    dropout_rate = 0.3
    activation = "relu"
    inputsize = 1
    window_size = 64

    # Test invert=False (LSTM first, then CNN)
    model_lstm_first = dlfiltertorch.HybridModel(
        num_filters=num_filters,
        kernel_size=kernel_size,
        num_units=num_units,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        activation=activation,
        inputsize=inputsize,
        window_size=window_size,
        invert=False,
    )
    model_lstm_first.eval()

    batch_size = 4
    x = torch.randn(batch_size, inputsize, window_size)
    output = model_lstm_first(x)
    assert output.shape == (batch_size, inputsize, window_size)

    config = model_lstm_first.get_config()
    assert config["invert"] is False
    assert config["num_filters"] == num_filters
    assert config["num_units"] == num_units

    # Test invert=True (CNN first, then LSTM)
    model_cnn_first = dlfiltertorch.HybridModel(
        num_filters=num_filters,
        kernel_size=kernel_size,
        num_units=num_units,
        num_layers=num_layers,
        dropout_rate=dropout_rate,
        activation=activation,
        inputsize=inputsize,
        window_size=window_size,
        invert=True,
    )
    model_cnn_first.eval()

    output_inv = model_cnn_first(x)
    assert output_inv.shape == (batch_size, inputsize, window_size)

    config_inv = model_cnn_first.get_config()
    assert config_inv["invert"] is True


def hybrid_dlfilter(testtemproot):
    """Test HybridDLFilter initialization, getname, makenet."""
    # Test with invert=False
    filter_obj = dlfiltertorch.HybridDLFilter(
        invert=False,
        num_filters=8,
        kernel_size=3,
        num_units=16,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="test",
    )

    assert filter_obj.nettype == "hybrid"
    assert filter_obj.invert is False

    filter_obj.getname()
    assert "hybrid" in filter_obj.modelname
    assert os.path.exists(filter_obj.modelpath)

    filter_obj.makenet()
    assert filter_obj.model is not None
    assert isinstance(filter_obj.model, dlfiltertorch.HybridModel)

    # Test predict
    val_x = np.random.randn(10, 64, 1).astype(np.float32)
    predictions = filter_obj.predict_model(val_x)
    assert predictions.shape == val_x.shape

    # Test with invert=True
    filter_obj_inv = dlfiltertorch.HybridDLFilter(
        invert=True,
        num_filters=8,
        kernel_size=3,
        num_units=16,
        window_size=64,
        num_layers=3,
        num_epochs=1,
        modelroot=testtemproot,
        namesuffix="testinv",
    )
    filter_obj_inv.getname()
    filter_obj_inv.makenet()
    predictions_inv = filter_obj_inv.predict_model(val_x)
    assert predictions_inv.shape == val_x.shape


def calcnumchannels_test():
    """Test calcnumchannels for all 4 combinations of usebadpts and dofft."""
    # No badpts, no fft
    numchans, badptchans, fftchans = dlfiltertorch.calcnumchannels(False, False)
    assert numchans == 1
    assert badptchans == 0
    assert fftchans == 0

    # With badpts, no fft
    numchans, badptchans, fftchans = dlfiltertorch.calcnumchannels(True, False)
    assert numchans == 2
    assert badptchans == 1
    assert fftchans == 0

    # No badpts, with fft
    numchans, badptchans, fftchans = dlfiltertorch.calcnumchannels(False, True)
    assert numchans == 3
    assert badptchans == 0
    assert fftchans == 2

    # With badpts, with fft
    numchans, badptchans, fftchans = dlfiltertorch.calcnumchannels(True, True)
    assert numchans == 4
    assert badptchans == 1
    assert fftchans == 2


def datatochannels_test():
    """Test datatochannels with various configurations."""
    length = 100
    timecourse = np.random.randn(length).astype(np.float64)
    badpts = np.zeros(length, dtype=np.float64)
    badpts[20:30] = 1.0

    # Basic: no badpts, no fft
    result = dlfiltertorch.datatochannels(timecourse, badpts, usebadpts=False, dofft=False)
    assert result.shape == (length, 1)
    assert np.allclose(result[:, 0], timecourse)

    # With badpts
    result_bp = dlfiltertorch.datatochannels(timecourse, badpts, usebadpts=True, dofft=False)
    assert result_bp.shape == (length, 2)
    assert np.allclose(result_bp[:, 1], badpts)
    # Data at bad points should be zeroed
    assert np.all(result_bp[20:30, 0] == 0.0)

    # With fft (no badpts)
    result_fft = dlfiltertorch.datatochannels(timecourse, badpts, usebadpts=False, dofft=True)
    assert result_fft.shape == (length, 3)
    assert np.allclose(result_fft[:, 0], timecourse)

    # With both badpts and fft
    result_both = dlfiltertorch.datatochannels(timecourse, badpts, usebadpts=True, dofft=True)
    assert result_both.shape == (length, 4)
    assert np.allclose(result_both[:, 1], badpts)

    # Zero signal should produce zero fft channels
    zero_tc = np.zeros(length, dtype=np.float64)
    result_zero = dlfiltertorch.datatochannels(zero_tc, badpts, usebadpts=False, dofft=True)
    assert result_zero.shape == (length, 3)
    assert np.allclose(result_zero[:, 1], 0.0)
    assert np.allclose(result_zero[:, 2], 0.0)


def filtscale_hybrid():
    """Test filtscale in hybrid mode."""
    data = np.random.randn(64)

    # Forward hybrid mode
    scaled_data, scalefac = dlfiltertorch.filtscale(data, hybrid=True, lognormalize=True)
    assert scaled_data.shape == (64, 2)
    # First column should be original data in hybrid mode
    assert np.allclose(scaled_data[:, 0], data)

    # Reverse hybrid mode returns just the first column (original data)
    reconstructed = dlfiltertorch.filtscale(
        scaled_data, scalefac=scalefac, reverse=True, hybrid=True
    )
    assert np.allclose(reconstructed, data)


def filtscale_roundtrip():
    """Test filtscale forward/reverse roundtrip for both log and linear normalization."""
    data = np.random.randn(128)

    # Roundtrip with log normalization
    scaled_log, sf_log = dlfiltertorch.filtscale(data, reverse=False, lognormalize=True)
    recon_log = dlfiltertorch.filtscale(
        scaled_log, scalefac=sf_log, reverse=True, lognormalize=True
    )
    assert recon_log.shape == data.shape
    assert mse(data, recon_log) < 0.1

    # Roundtrip with linear normalization
    scaled_lin, sf_lin = dlfiltertorch.filtscale(data, reverse=False, lognormalize=False)
    recon_lin = dlfiltertorch.filtscale(
        scaled_lin, scalefac=sf_lin, reverse=True, lognormalize=False
    )
    assert recon_lin.shape == data.shape
    assert mse(data, recon_lin) < 1e-10


def test_dlfilterops(debug=False, local=False):
    # set input and output directories
    testtemproot = get_test_temp_path(local)

    thedummydata = create_dummy_data()

    if debug:
        print("cnn_model_creation()")
    cnn_model_creation()

    if debug:
        print("cnn_dlfilter_initialization(testtemproot)")
    cnn_dlfilter_initialization(testtemproot)

    if debug:
        print("cnn_dlfilter_initialize(testtemproot)")
    cnn_dlfilter_initialize(testtemproot)

    if debug:
        print("predict_model(testtemproot, thedummydata)")
    predict_model(testtemproot, thedummydata)

    if debug:
        print("apply_method(testtemproot)")
    apply_method(testtemproot)

    if debug:
        print("apply_method_with_badpts(testtemproot)")
    apply_method_with_badpts(testtemproot)

    if debug:
        print("save_and_load_model(testtemproot)")
    save_and_load_model(testtemproot)

    if debug:
        print("filtscale_forward()")
    filtscale_forward()

    if debug:
        print("filtscale_reverse()")
    filtscale_reverse()

    if debug:
        print("tobadpts()")
    tobadpts()

    if debug:
        print("targettoinput()")
    targettoinput()

    if debug:
        print("model_with_different_activations(testtemproot)")
    model_with_different_activations(testtemproot)

    if debug:
        print("device_selection()")
    device_selection()

    if debug:
        print("infodict_population(testtemproot)")
    infodict_population(testtemproot)

    if debug:
        print("self_attention_model()")
    self_attention_model()

    if debug:
        print("ppg_attention_model_creation()")
    ppg_attention_model_creation()

    if debug:
        print("ppg_attention_dlfilter(testtemproot)")
    ppg_attention_dlfilter(testtemproot)

    if debug:
        print("dense_autoencoder_model_creation()")
    dense_autoencoder_model_creation()

    if debug:
        print("dense_autoencoder_dlfilter(testtemproot)")
    dense_autoencoder_dlfilter(testtemproot)

    if debug:
        print("conv_autoencoder_model_creation()")
    conv_autoencoder_model_creation()

    if debug:
        print("conv_autoencoder_dlfilter(testtemproot)")
    conv_autoencoder_dlfilter(testtemproot)

    if debug:
        print("multiscale_cnn_model_creation()")
    multiscale_cnn_model_creation()

    if debug:
        print("multiscale_cnn_dlfilter(testtemproot)")
    multiscale_cnn_dlfilter(testtemproot)

    if debug:
        print("crnn_model_creation()")
    crnn_model_creation()

    if debug:
        print("crnn_dlfilter(testtemproot)")
    crnn_dlfilter(testtemproot)

    if debug:
        print("lstm_model_creation()")
    lstm_model_creation()

    if debug:
        print("lstm_dlfilter(testtemproot)")
    lstm_dlfilter(testtemproot)

    if debug:
        print("hybrid_model_creation()")
    hybrid_model_creation()

    if debug:
        print("hybrid_dlfilter(testtemproot)")
    hybrid_dlfilter(testtemproot)

    if debug:
        print("calcnumchannels_test()")
    calcnumchannels_test()

    if debug:
        print("datatochannels_test()")
    datatochannels_test()

    if debug:
        print("filtscale_hybrid()")
    filtscale_hybrid()

    if debug:
        print("filtscale_roundtrip()")
    filtscale_roundtrip()


if __name__ == "__main__":
    test_dlfilterops(debug=True, local=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   Copyright 2016-2026 Blaise Frederick
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#
import os
import subprocess
from os.path import join as pjoin

import rapidtide.io as tide_io
import rapidtide.util as tide_util


def fslinfo() -> str | None:
    """
    Get FSL directory path from environment variable.

    This function retrieves the FSL directory path from the FSLDIR environment
    variable. It also sets a global flag `fslexists` to indicate whether FSL
    is available in the current environment.

    Returns
    -------
    str or None
        The path to the FSL directory if FSLDIR environment variable is set,
        otherwise None.

    Notes
    -----
    This function modifies the global variable `fslexists` which is set to
    True if FSLDIR is found, False otherwise. The function does not perform
    any validation of the FSL directory existence or integrity.

    Examples
    --------
    >>> fslinfo()
    '/usr/local/fsl'  # if FSLDIR is set
    >>> fslinfo()
    None  # if FSLDIR is not set
    """
    global fslexists
    fsldir = os.environ.get("FSLDIR")
    if fsldir is not None:
        fslexists = True
    else:
        fslexists = False
    return fsldir


def whatexists() -> tuple[bool, bool, bool]:
    """
    Check for existence of FSL, c3d, and ANTS executables.

    This function checks whether the FSL directory is set in the environment
    and verifies the existence of c3d_affine_tool and antsApplyTransforms
    executables in the system PATH.

    Returns
    -------
    tuple[bool, bool, bool]
        A tuple containing three boolean values:
        - First value: True if FSLDIR environment variable is set, False otherwise
        - Second value: True if c3d_affine_tool executable is found, False otherwise
        - Third value: True if antsApplyTransforms executable is found, False otherwise

    Notes
    -----
    The function uses os.environ.get() to check for FSLDIR and tide_util.isexecutable()
    to check for executable existence. The results are printed to stdout for debugging
    purposes.

    Examples
    --------
    >>> whatexists()
    c3dexists = True
    antsexists = False
    (True, True, False)
    """
    fsldir = os.environ.get("FSLDIR")
    if fsldir is not None:
        fslexists = True
    else:
        fslexists = False

    c3dexists = tide_util.isexecutable("c3d_affine_tool")
    print("c3dexists =", c3dexists)
    antsexists = tide_util.isexecutable("antsApplyTransforms")
    print("antsexists =", antsexists)
    return fslexists, c3dexists, antsexists


def getfslcmds() -> tuple[str | None, str | None, str | None]:
    """
    Get paths to FSL command executables.

    This function retrieves the paths to three core FSL commands (fsl_sub, flirt, and applywarp)
    by looking up the FSLDIR environment variable. If FSLDIR is not set, all returned paths will be None.

    Returns
    -------
    tuple[str | None, str | None, str | None]
        A tuple containing three elements:
        - fslsubcmd: Path to fsl_sub command, or None if FSLDIR is not set
        - flirtcmd: Path to flirt command, or None if FSLDIR is not set
        - applywarpcmd: Path to applywarp command, or None if FSLDIR is not set

    Notes
    -----
    The function expects the FSLDIR environment variable to be set to the FSL installation directory.
    The returned paths are constructed by joining the FSLDIR with "bin/fsl_sub", "bin/flirt", and "bin/applywarp".

    Examples
    --------
    >>> fslsub, flirt, applywarp = getfslcmds()
    >>> print(fslsub)
    '/usr/local/fsl/bin/fsl_sub'  # if FSLDIR is set
    >>> print(flirt)
    '/usr/local/fsl/bin/flirt'    # if FSLDIR is set
    >>> print(applywarp)
    '/usr/local/fsl/bin/applywarp' # if FSLDIR is set
    """
    fsldir = os.environ.get("FSLDIR")
    if fsldir is not None:
        fslsubcmd = os.path.join(fsldir, "bin", "fsl_sub")
        flirtcmd = os.path.join(fsldir, "bin", "flirt")
        applywarpcmd = os.path.join(fsldir, "bin", "applywarp")
    else:
        fslsubcmd = None
        flirtcmd = None
        applywarpcmd = None
    return fslsubcmd, flirtcmd, applywarpcmd


def runcmd(thecmd: list[str], fake: bool = False, debug: bool = False) -> None:
    """
    Execute a command using subprocess.call or simulate execution.

    This function executes a command represented as a list of strings using
    subprocess.call. It can also simulate command execution for testing purposes
    when the 'fake' parameter is set to True.

    Parameters
    ----------
    thecmd : list[str]
        Command to execute, represented as a list of strings where the first
        element is the command and subsequent elements are arguments.
    fake : bool, optional
        If True, print the command that would be executed without actually
        running it. Default is False.
    debug : bool, optional
        If True, print the command before executing or simulating. Default is False.

    Returns
    -------
    None
        This function does not return any value.

    Notes
    -----
    The function uses subprocess.call to execute commands, which means it will
    block until the command completes. The 'fake' mode is useful for testing
    without actually executing commands.

    Examples
    --------
    >>> runcmd(['ls', '-l'])
    # Executes 'ls -l' command

    >>> runcmd(['echo', 'hello'], fake=True)
    # Prints: echo hello
    # But does not actually execute the echo command

    >>> runcmd(['python', '--version'], debug=True)
    # Prints: ['python', '--version']
    # Then executes the command
    """
    if debug:
        print(thecmd)
    if fake:
        print(" ".join(thecmd))
        print()
    else:
        subprocess.call(thecmd)


def makeflirtcmd(
    inputfile: str,
    targetname: str,
    xform: str,
    outputname: str,
    warpfile: str | None = None,
    cluster: bool = False,
    debug: bool = False,
) -> list[str]:
    """
    Create FSL FLIRT command for image registration.

    This function generates a command list for FSL's FLIRT tool to perform either
    linear or nonlinear image registration depending on whether a warp file is provided.

    Parameters
    ----------
    inputfile : str
        Path to the input image file to be registered
    targetname : str
        Path to the target reference image
    xform : str
        Path to the transformation matrix file (for linear registration)
    outputname : str
        Path where the registered output image will be saved
    warpfile : str, optional
        Path to the warp field file for nonlinear registration. If None,
        linear registration is performed (default is None)
    cluster : bool, optional
        If True, prefix the command with fslsub for cluster execution (default is False)
    debug : bool, optional
        If True, print the constructed command for debugging purposes (default is False)

    Returns
    -------
    list[str]
        List of command arguments that can be executed using subprocess or similar

    Notes
    -----
    - For linear registration, the function uses FLIRT with the -applyxfm flag
    - For nonlinear registration, the function uses applywarp instead of FLIRT
    - The function prints transformation type information to stdout

    Examples
    --------
    >>> cmd = makeflirtcmd('input.nii', 'target.nii', 'xform.mat', 'output.nii')
    >>> print(' '.join(cmd))
    flirt -in input.nii -ref target.nii -applyxfm -init xform.mat -out output.nii

    >>> cmd = makeflirtcmd('input.nii', 'target.nii', 'xform.mat', 'output.nii', 'warp.nii')
    >>> print(' '.join(cmd))
    applywarp --ref=target.nii --in=input.nii --out=output.nii --warp=warp.nii
    """
    fslsubcmd, flirtcmd, applywarpcmd = getfslcmds()
    thecommand = []
    if warpfile is None:
        print("doing linear transformation")
        if cluster:
            thecommand.append(fslsubcmd)
        thecommand.append(flirtcmd)
        thecommand.append("-in")
        thecommand.append(inputfile)
        thecommand.append("-ref")
        thecommand.append(targetname)
        thecommand.append("-applyxfm")
        thecommand.append("-init")
        thecommand.append(xform)
        thecommand.append("-out")
        thecommand.append(outputname)
    else:
        print("doing nonlinear transformation")
        if cluster:
            thecommand.append(fslsubcmd)
        thecommand.append(applywarpcmd)
        thecommand.append("--ref=" + targetname)
        thecommand.append("--in=" + inputfile)
        thecommand.append("--out=" + outputname)
        thecommand.append("--warp=" + warpfile)
    if debug:
        print(f"MAKEFILIRTCMD: {thecommand}")
    return thecommand


def runflirt(
    inputfile: str,
    targetname: str,
    xform: str,
    outputname: str,
    warpfile: str | None = None,
    fake: bool = False,
    debug: bool = False,
) -> None:
    """
    Run FLIRT (FMRIB's Linear Image Registration Tool) for image registration.

    This function constructs and executes a FLIRT command for linear image registration
    between an input file and a target file. It supports various transformation types
    and can optionally generate warp fields for non-linear registration.

    Parameters
    ----------
    inputfile : str
        Path to the input image file to be registered
    targetname : str
        Path to the target image file for registration
    xform : str
        Transformation type to use (e.g., 'rigid', 'affine', 'syn')
    outputname : str
        Path where the registered output image will be saved
    warpfile : str, optional
        Path to save the warp field file (default is None)
    fake : bool, optional
        If True, only print the command without executing it (default is False)
    debug : bool, optional
        If True, enable debug mode with additional output (default is False)

    Returns
    -------
    None
        This function does not return any value

    Notes
    -----
    This function relies on the `makeflirtcmd` function to construct the command
    and `runcmd` function to execute it. The actual FLIRT command execution
    is delegated to these helper functions.

    Examples
    --------
    >>> runflirt('input.nii.gz', 'target.nii.gz', 'affine', 'output.nii.gz')
    >>> runflirt('input.nii.gz', 'target.nii.gz', 'rigid', 'output.nii.gz',
    ...          warpfile='warpfield.nii.gz', fake=True)
    """
    thecommand = makeflirtcmd(inputfile, targetname, xform, outputname, warpfile=warpfile)
    runcmd(thecommand, fake=fake, debug=debug)


def n4correct(inputfile: str, outputdir: str, fake: bool = False, debug: bool = False) -> None:
    """
    Apply N4 bias field correction to MRI images.

    This function performs N4 bias field correction using the ANTs N4BiasFieldCorrection
    tool. It corrects intensity inhomogeneities in MRI images by estimating and removing
    the bias field component from the input image.

    Parameters
    ----------
    inputfile : str
        Path to the input NIfTI image file to be corrected
    outputdir : str
        Directory path where the corrected output file will be saved
    fake : bool, optional
        If True, only print the command that would be executed without actually running it
        Default is False
    debug : bool, optional
        If True, enable debug mode to print additional information during execution
        Default is False

    Returns
    -------
    None
        This function does not return any value but saves the corrected image to the
        specified output directory

    Notes
    -----
    The output file will be saved with the naming convention: {input_filename}_n4{file_extension}

    Examples
    --------
    >>> n4correct('subject1.nii.gz', '/path/to/output')
    >>> n4correct('subject1.nii.gz', '/path/to/output', fake=True, debug=True)

    See Also
    --------
    tide_io.niftisplitext : Function used to split filename and extension
    runcmd : Function used to execute the N4 command
    """
    thename, theext = tide_io.niftisplitext(inputfile)
    n4cmd = []
    n4cmd += ["N4BiasFieldCorrection"]
    n4cmd += ["-d", "3"]
    n4cmd += ["-i", inputfile]
    n4cmd += ["-o", pjoin(outputdir, thename + "_n4" + theext)]
    runcmd(n4cmd, fake=fake, debug=debug)


def antsapply(
    inputname: str,
    targetname: str,
    outputroot: str,
    transforms: list[str],
    fake: bool = False,
    debug: bool = False,
) -> None:
    """
    Apply ANTs transforms to an input image using antsApplyTransforms.

    This function constructs and executes an antsApplyTransforms command to apply
    a series of transforms to an input image, resampling it to match a target image.

    Parameters
    ----------
    inputname : str
        Path to the input image to be transformed
    targetname : str
        Path to the target image (reference space) for resampling
    outputroot : str
        Root name for the output file (without extension)
    transforms : list[str]
        List of transform files to apply in order
    fake : bool, optional
        If True, only print the command without executing it (default: False)
    debug : bool, optional
        If True, print additional debug information (default: False)

    Returns
    -------
    None
        This function does not return a value but executes the antsApplyTransforms command

    Notes
    -----
    The function uses antsApplyTransforms with the following fixed parameters:
    - Default value set to 0
    - Dimensionality set to 3
    - Uses the target image as reference for resampling

    Examples
    --------
    >>> antsapply('input.nii.gz', 'target.nii.gz', 'output', ['transform1.nii.gz', 'transform2.nii.gz'])
    >>> antsapply('input.nii.gz', 'target.nii.gz', 'output', ['transform1.nii.gz'], fake=True)
    """
    applyxfmcmd = []
    applyxfmcmd += ["antsApplyTransforms"]
    applyxfmcmd += ["--default-value", "0"]
    applyxfmcmd += ["-d", "3"]
    applyxfmcmd += ["-i", inputname]
    applyxfmcmd += ["-o", outputroot]
    applyxfmcmd += ["-r", targetname]
    for thetransform in transforms:
        applyxfmcmd += ["--transform", thetransform]
    runcmd(applyxfmcmd, fake=fake, debug=debug)
